@@ -28,7 +28,7 @@ class Engine(object):
 
     def get_image_descriptor(self, image):
         if isinstance(image, ImageFile):
-            raise NotImplementedError("Django files is not implemented")
+            return ImageDescriptor.create_from_file(image.path)
         elif isinstance(image, string_types):
             return ImageDescriptor.create_from_file(image)
         elif not image:
