@@ -14,10 +14,10 @@ class Color:
         self.a = a
 
     def normalize(self):
-        self.r = math.ceil(self.r)
-        self.g = math.ceil(self.g)
-        self.b = math.ceil(self.b)
-        self.a = math.ceil(self.a)
+        self.r = int(math.ceil(self.r))
+        self.g = int(math.ceil(self.g))
+        self.b = int(math.ceil(self.b))
+        self.a = int(math.ceil(self.a))
 
     @property
     def to_tuple(self):
