@@ -32,15 +32,19 @@ class ImageFilter(object):
 
 
 class PixelImageFilter(ImageFilter):
-    def process_pixel(self, color, options):
+    def process_options(self, options):
+        pass
+
+    def process_pixel(self, color):
         raise NotImplementedError()
 
     def process_image(self, image, options):
         new_data = []
         for item in image.getdata():
             old_color = Color(item[0], item[1], item[2], item[3])
-            new_color = self.process_pixel(old_color, options)
+            new_color = self.process_pixel(old_color)
             new_color.normalize()
             new_data.append(new_color.to_tuple)
         image.putdata(new_data)
+        self.process_options(options)
         return image
