@@ -29,6 +29,9 @@ class GrayscaleFilter(PixelImageFilter):
         i = 0.21 * c.r + 0.72 * c.g + 0.07 * c.b
         return Color(i, i, i, c.a)
 
-    def process_pixel(self, c, options):
+    def process_pixel(self, c):
         process_pixel = getattr(self, self.mode, None)
         return process_pixel(c)
+
+    def process_options(self, options):
+        options.is_preserve_format = False
