@@ -36,8 +36,9 @@ class ResizeFilter(ImageFilter):
         raise ValueError("Size must be tuple of two elements or string in '[width]x[height]' format")
 
     def initialize(self, size=None, **options):
-        self.size = self.reinterpret_size(size)
-        self.is_full = self.normalize_size == self.size
+        if size:
+            self.size = self.reinterpret_size(size)
+            self.is_full = self.normalize_size == self.size
         self.is_enabled = bool(self.size)
 
     @property
@@ -63,8 +64,8 @@ class ResizeFilter(ImageFilter):
 
             # expand image to size
             size = thumbnail_image.size
-            x = int(math.ceil((self.size[0] - size[0]) / 2))
-            y = int(math.ceil((self.size[1] - size[1]) / 2))
+            x = int(math.ceil(float(self.size[0] - size[0]) / 2))
+            y = int(math.ceil(float(self.size[1] - size[1]) / 2))
             resize_image = Image.new(thumbnail_image.mode, self.size)
             resize_image.paste(thumbnail_image, (x, y, x + size[0], y + size[1]))
             thumbnail_image = resize_image
